@@ -155,8 +155,8 @@ Optional argument ARGS as per `browse-url-default-browser'"
   (cl-assert (string-match-p "^http[s]?://" (current-kill 0)) nil "Not a URL")
   (dwim-shell-command-on-marked-files
    "Downloading"
-   "youtube-dl --newline -o \"~/Downloads/%(title)s.%(ext)s\" \"<<cb>>\""
-   :utils "youtube-dl"
+   "yt-dlp --newline -o \"~/Downloads/%(title)s.%(ext)s\" \"<<cb>>\""
+   :utils "yt-dlp"
    :no-progress t
    :error-autofocus t
    :monitor-directory "~/Downloads"
@@ -357,6 +357,17 @@ Optional argument ARGS as per `browse-url-default-browser'"
             :default "joined.pdf"))
    :utils "convert"))
 
+;;;###autoload
+(defun dwim-shell-commands-kdeconnect-share ()
+  "Send file(s) to a device through KDE Connect."
+  (interactive)
+  (let* ((devices (process-lines "kdeconnect-cli" "--list-available" "--name-only"))
+         (device (completing-read "Device: " devices nil t)))
+    (dwim-shell-command-on-marked-files
+     "Send file(s) to DEVICE through KDE Connect."
+     (format "kdeconnect-cli -n '%s' --share '<<f>>'" device)
+     :utils "kdeconnect-cli")))
+
 ;;;###autoload
 (defun dwim-shell-commands-keep-pdf-page ()
   "Keep a page from pdf."
